import AsyncStorage from "@react-native-async-storage/async-storage";
import { createAsyncThunk, createSlice } from "@reduxjs/toolkit";
import { useDispatch, useSelector } from "react-redux";
const initialState = {
  dark: false,
  initializing: true
};
export const asyncInitTheme = createAsyncThunk("asyncInitTheme", async () => {
  const dark = await AsyncStorage.getItem("dark");
  return Boolean(dark);
});
export const ThemeSlice = createSlice({
  name: "ThemeSlice",
  initialState,
  reducers: {
    setDark: (state, {
      payload
    }) => {
      state.dark = payload;
      console.log(payload);
      AsyncStorage.setItem("dark", String(payload));
    }
  },
  extraReducers: builder => {
    builder.addCase(asyncInitTheme.pending, state => {
      state.initializing = true;
    }).addCase(asyncInitTheme.fulfilled, (state, {
      payload
    }) => {
      state.initializing = false;
      state.dark = payload;
    }).addCase(asyncInitTheme.rejected, state => {
      state.initializing = false;
    });
  }
});
const actions = ThemeSlice.actions;
export function useThemeMode() {
  const theme = useSelector(state => state.theme);
  const dispatch = useDispatch();
  const toggleDarkMode = () => {
    dispatch(actions.setDark(!theme.dark));
  };
  return {
    ...theme,
    toggleDarkMode
  };
}
//# sourceMappingURL=ThemeSlice.js.map